# Generated by Django 2.2.8 on 2020-04-09 16:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('entity_event', '0004_auto_20180403_1655'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contextrenderer',
            name='name',
            field=models.CharField(max_length=256, unique=True),
        ),
        migrations.AlterField(
            model_name='medium',
            name='display_name',
            field=models.CharField(max_length=256),
        ),
        migrations.AlterField(
            model_name='medium',
            name='name',
            field=models.CharField(max_length=256, unique=True),
        ),
        migrations.AlterField(
            model_name='renderingstyle',
            name='display_name',
            field=models.CharField(default='', max_length=256),
        ),
        migrations.AlterField(
            model_name='renderingstyle',
            name='name',
            field=models.CharField(max_length=256, unique=True),
        ),
        migrations.AlterField(
            model_name='source',
            name='display_name',
            field=models.CharField(max_length=256),
        ),
        migrations.AlterField(
            model_name='source',
            name='name',
            field=models.CharField(max_length=256, unique=True),
        ),
        migrations.AlterField(
            model_name='sourcegroup',
            name='display_name',
            field=models.CharField(max_length=256),
        ),
        migrations.AlterField(
            model_name='sourcegroup',
            name='name',
            field=models.CharField(max_length=256, unique=True),
        ),
    ]
