# -*- coding: utf-8 -*-
# Generated by Django 1.11.11 on 2018-04-03 16:55
from __future__ import unicode_literals

import django.contrib.postgres.fields.jsonb
import django.core.serializers.json
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('entity_event', '0003_auto_20170830_1321'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contextrenderer',
            name='context_hints',
            field=django.contrib.postgres.fields.jsonb.JSONField(default=None, encoder=django.core.serializers.json.DjangoJSONEncoder, null=True),
        ),
        migrations.AlterField(
            model_name='event',
            name='context',
            field=django.contrib.postgres.fields.jsonb.JSONField(encoder=django.core.serializers.json.DjangoJSONEncoder),
        ),
        migrations.AlterField(
            model_name='medium',
            name='additional_context',
            field=django.contrib.postgres.fields.jsonb.JSONField(default=None, encoder=django.core.serializers.json.DjangoJSONEncoder, null=True),
        ),
    ]
